---
Title: Architecture overview
Author: Jutta
Topics:
  - servers, repositories, webpages
Reviewer: Jannik
status: reviewed
---
# The KM3NeT open science system

## Platforms for Open Science

The KM3NeT Open Science System seamlessly integrates with the computing environment of the KM3NeT Collaboration, providing data, software and documentation to all relevant parts of the scientific analysis workflow.

![Infrastructure overview](/figures/infrastructure_overview.png)

### Open Science Products

The products offered from the various servers include not only data, but also software and supplementary material.

#### Data sets
Only [high-level data sets](Processing.md#high-level-data-and-data-derivatives) and derivatives are offered in the open science platforms. These include:

* Particle events from **[optical neutrino detection](Detector.md#data-acquisition)**, which is the prinary data production channel for KM3NeT.
* **[Multi-messenger alert data](Multimessenger.md)** which is broadcast for events with high scientific relevance in multi-messenger searches.
* **[Environmental data](SeaScience.md)** from both calibration-relevant data for the deep-sea detector and acoustic data for UHE neutrino detection which is relevant to Sea Science.

#### High-level derivatives
For the evaluation of the significance of the data for a given analysis target, additional information crucial to the interpretation of the data is published. These include:

* Binned and paramterized information drawn from **[simulations](Simulation.md)**, e.g. instrument response functions or sensitivities.
* High-level data **summary information** from dedicated analyses, e.g. public plots.

#### Software and workflows
Software and workflow examples facilitate the processing of the open data and form the basis for community-oriented developments. Offered products are:

* **KM3NeT-related software** for data processing, simulation and analysis.
* **[Interface packages](Python.md#python-interface-to-km3net-data)** for data access, currently based on python.
* **Workflow descriptions** as Jupyter notebooks or annotated workflows for data handling.

#### Tutorials and Documentation
Documentation is set up to provide a linear step-by-step approach to the use of KM3NeT data as well as broad documenation on the specific details for user-oriented specific information, namely

* overview description of the KM3NeT open data system,
* **documentation** of all components, and
* training and **online courses** for guided approaches to the use of the data

### KM3NeT servers and platforms
The products are published through various platforms tailored specifically to the requirements for sharing of the specific product.

#### Data servers
* Astrophysics-related data is offered through the **[KM3NeT Virtual Observatory server](VOserver.md)** running the VO-integrated [DaCHS software](https://dachs-doc.readthedocs.io/index.html).
* All services and data not integrateable into the VO due to their different scientific domain or technical nature are offered through the [KM3NeT Open Data Center](KM3NeTserver.md) offering webpages and a REST-API to query the data products.

#### Software servers
* All software is offered through an KM3NeT-operated **[Gitlab server](Git.md)** which hosts all software and documentation projects.
* Containers with key software are packaged and made available through a **[Docker server](Docker.md)**.

#### Documentation & Courses
Documentation is widely spread through the system and generally offered as closely as possible to the actual product. Dedicated platforms offering centralized knowledge access are

* the **[Education portal](Courses.md)** for tutorials and webinars, and
* Gitlab projects and pages, especially the **[Open Science Portal](https://open-data.pages.km3net.de/openscienceportal/)** which documents the KM3NeT open science system.

### Interfaces

For the end user, various access options to data, software and documentation are offered.

#### Repositories
Data is registered to large [centralized data registries](Repositories.md) which make the KM3NeT data findable by the wider community. These registries include

* the **[VO registry](https://doi.org/10.1016/j.ascom.2014.07.001)** to which all data sets and services registered through the VO server are pushed, and
* the [Zenodo repository](https://zenodo.org/) or alternative solution to integrate with **[DataCite](https://datacite.org/)**.

#### Web interfaces
The platforms themselves offer various options to acces the data, namely

* webpages, query forms and REST-APIs using both Graphical User Interfaces (GUIs) and machine-accessible endpoints, and
* domain-specific access protocols like TAP or ADQL for the VO-related data.

#### Software clients
Clients for user-friendly handling of the data are offered by third parties as well as by KM3NeT, including

* VO-specific access tools like [TOPCAT](http://www.star.bris.ac.uk/~mbt/topcat/) or the [Aladin Sky Atlas](https://aladin.u-strasbg.fr/), and
* python packages from third parties like [pyvo](https://pypi.org/project/pyvo/) or dedicated KM3NeT software like openkm3.


