---
Title: KM3NeT use case
Author: Steffen
Topics:
  - short description analysis
  - data description
  - linking to notebooks & background
status: reviewed
Reviewer: Jannik
Note from reviewer: Jupyter notebooks NOT reviewied in detail, justed skimmed over.
---

## KM3NeT Use Case

### Summary

* Dataset to show use of KM3NeT data using a atmospheric muon dominated event sample.
* Runs selected from KM3NeT/ORCA taken with four Detection Units according to quality criteria.
* Processed to metadata enriched hdf5.
* Analysis examples provided as jupyter notebooks.


### Analysis of atmospheric muon dominated dataset
The provided KM3NeT use case contains a dataset with triggered events reconstructed with 4 Detection Units of KM3NeT/ORCA. It is therefore dominated by atmospheric muon events (several Hz, compared to atmospheric neutrino rate of ~mHz) reaching the detector from above. The recorded and reconstructed dataset is provided on the KM3NeT VO server [1] in hdf5 format for download. This is used for analysis with jupyter notebooks.

### Run selection and online sample
For the online sample the recorded ORCA runs are pre-selected by imposing requirements on variables stored in the database:

- 'PHYSICS' runs (i.e. no calibration runs, etc.)
- long runs (>2h duration)
- less than 100s recorded livetime missing with respect to the run duration in the database
- runs with fairly low optival rates (a 'High Rate Veto' (HRV) variable is used, indicating the time-averaged fraction of photo-sensors with too high rates (20kHz) due to optical background noise. Runs with HRV fraction < 0.2 are selected)       

### Processing to metadata enriched hdf5 format
For the demonstration, a range of data-taking runs meeting the run selection criteria above is published on the KM3NeT VO server [1].  

The provided online hdf5 dataset contains all triggered events satisfying all three trigger conditions of KM3NeT/ORCA. The data sample currently contains events reconstructed with the track reconstruction algorithm JGandalf. In addition to the basic event features needed for analysis, *time*, *zenith*, *azimuth*, *energy*, it contains also other features provided by the reconstruction algorithm, an estimate for the *angular error*, reconstruction *quality* and number of signal hits used in the reconstruction (*nhit*). More sophisticated high-level variables allowing to select a pure neutrino sample are not available for the time being, but will be added in the future.

The dataset was processed from the Collaboration analysis format aanet to hdf5 format, and enriched with metadata describing the provenance and contents of the file.

### Analysis examples

#### Requirements
Jupyter notebooks are based on python3 and require mostly packages installable via pip.

Analysis examples 1-4:
  * pip installable packages (astropy, numpy, matplotlib)
  * openkm3 (`pip install git+https://git.km3net.de/jschnabel/openkm3`)
  * kmeta (`pip install git+https://git.km3net.de/jschnabel/kmeta`)

Analysis example 4 only:
  * Aladin: https://aladin.u-strasbg.fr/java/nph-aladin.pl?frame=downloading .
  * TOPCAT: http://www.star.bris.ac.uk/~mbt/topcat/#install .


#### Description of KM3NeT/ORCA use cases
The jupyter notebooks for the KM3NeT use case are available under [2].

The dataset provided [1] contains reconstructed events. While the reconstruction parameters provided at the moment are in-sufficient to produce a pure atmospheric or even astrophysical neutrino sample, the general procedure can be motivated unitl in future, single or few-parameter high-level event selection variables are available for a genuine neutrino analysis.

With this precondition, four analysis examples are provided as KM3NeT use-case:

- **A01)** In the first example the hdf5 data file is retrieved from the KM3NeT server, the continuity of data-taking and the event distribution in local coordinates is analysed
- **A02)** In the second example, the use of the reconstructed direction but also the other quality parameters contained in the hdf5 file is outlined in order to select 'interesting' events. Here 'interesting' events could possibly be neutrino candidates, however no quantitative evaluation of the probability to be indeed of neutrino origin is given.
- **A03)** The provided event sample is converted and visualised in galactic coordinates
- **A04)** The hdf5 dataset is retrieved and space coordinates are added. The event sample is then used to search for events coincident in space and time with a Gravitational Wave (GW) event.

#### References

[1] [http://vo.km3net.de:82/storage/one_week_orca.h5](http://vo.km3net.de:82/storage/one_week_orca.h5)

[2] [https://git.km3net.de/shallmann/orca_vo/-/tree/openkm3_usage/openkm3_usecase_orca](https://git.km3net.de/shallmann/orca_vo/-/tree/openkm3_usage/openkm3_usecase_orca)
