---
Title: VOserver
Author: Jutta
status: review
---

## Platforms and Servers

### The Virtual Observatory server

The Virtual Observatory environment facilitates data publication and sharing among astrophysics community according to the standards set by the [IVOA](https://ivoa.net/). The VO protocols implement the FAIR data principles and ensure an environment for better scientific use and public access to data from astrophysical experiments. 

Dedicated software and exchange protocols are set up at participating data centers and tailored user programs grant easy user access to the diverse data through standardized labeling and description of the data. The KM3NeT collaboration is a data provider to the VO and operates a data server at [http://vo.km3net.de/](http://vo.km3net.de/), running the (DaCHS software)[http://docs.g-vo.org/DaCHS/].

#### Implementation

**Software package**

The [GAVO Data Center Helper Suite (DaCHS)](https://dachs-doc.readthedocs.io/index.html) is a "publishing infrastructure for the Virtual Observatory, including a flexible component for ingesting and mapping data, integrated metadata handling with a publishing registry, and support for many VO protocols and standards". It can be applied for KM3NeT purposes "as is" and allows to various types of data and formats to the VO.

**Standards for metadata**
Entries to the VO registry are annotated using the [Resource Metadata standards](https://www.ivoa.net/documents/RM/20070302/index.html) of the IVOA. This metadata is required for publication. In the KM3NeT open science system, the KM3OpenResource class used to label all resources contains also entries which can be matched to the VO metadata standards, facilitating an automatic casting of the standard KM3NeT internal data format to the VO metadata.

#### Data conversion and upload

**Format conversion**

In order to transform event-based data to a VO-compatible format, [standard scripts](https://git.km3net.de/open-data/voserver) have been set up to convert [neutrino event tables](Dataformats.md#particle-event-tables) and the according metadata into VO-compatible format and add the required metadata to the data set. To publish a dataset, the procedure includes

* labeling the data set according to VO standards with information about origin, 
authorship, parameter formats and standardized event identifiers. In the DaCHS software, this is handled through a resource description file, to which information from the KM3OpenResource description is cast.
* Selection of the service interface, i.e. the protocols which are offered through the various endpoints of the server to the Virtual Observatory. This interface is also defined in the resource description.

**Publication procedure**

Publication involves uploading and listing the data set as available in the registry of the server, which is handled through simple [administration commands]() in DaCHS.

#### Interlink to registries

In order to declare the entries of the local server to the [IVOA Registry of Registries](http://rofr.ivoa.net/), the KM3NeT collaboration registered the server, obtaining a IVOA identifier (ivo://km3net.org) used in the VO context to 

#### Example data

As KM3NeT does not produce astrophysics data yet, an alternative data sample from the [ANTARES experiment](https://antares.in2p3.fr/) was used to set up the system. The ANTARES collaboration has already published two data sets to the VO by using the services of the German Astrophysical Virtual Observatory (GAVO) which runs the DaCHS software and is maintainer of it. The most recent public data sample was only made available through the ANTARES website and thus did not match the FAIR criteria. Using the [ANTARES 2007-2017 point source neutrino sample](Usecase_ANTARES.md), the KM3NeT VO server could be registered to the VO and hosts this data set as example data.

#### Data access
Tabulated high-level neutrino event data can be accessed utilizing access protocols like the Table Access Protocol (TAP) and query languages like the Astronomical Data Query Language (ADQL). To query these data sets related to astronomical sources, the Simple Cone Search (SCS) protocol allows to pick specific events according to particle source direction. 




